@@ -10,12 +10,16 @@ function createInstructorToolsMenu(){
         newselect.id = 'InstructorToolsmnu';
         newselect.classList.add('form-control'); //class to match notebook formatting
         newselect.classList.add('select-xs'); //class to match notebook formatting
+        newselect.setAttribute('style','color:blue;');
         newselect.onchange=function(){
             var lastvalue = this.value;
             this.value='Instructor Tools';
             if (lastvalue=='Insert Data Entry Table...'){
                 get_table_dim();
             }
+            if (lastvalue=='Mark Cell as Instructions'){
+                indicate_cell_contains_instructions();
+            }
             if (lastvalue=='Protect Selected Cells'){
                 protect_selected_cells();
             }
@@ -25,6 +29,21 @@ function createInstructorToolsMenu(){
             if (lastvalue=='Indicate Protected Cells'){
                 mark_protected_cells();
             }
+            if (lastvalue=='Allow Hiding Selected Cells'){
+                set_hide_selected_cells_on_print();
+            }
+            if (lastvalue=='Disallow Hiding Selected Cells'){
+                unset_hide_selected_cells_on_print();
+            }
+            if (lastvalue=='Indicate Cells Allowed to Hide'){
+                mark_hide_on_print_cells();
+            }
+            if (lastvalue=='Test Hide Cells'){
+                JPSLUtils.hide_hide_on_print_cells();
+            }
+            if (lastvalue=='Undo Hide Cells'){
+                JPSLUtils.show_hide_on_print_cells();
+            }
             if (lastvalue=='Insert get names and timestamp'){
                 insert_getnames_timestamp();
             }
@@ -38,16 +57,40 @@ function createInstructorToolsMenu(){
                 insert_init_boilerplate();
             }
         }
-        var optiontxt = '<option title="Insert an Instructor Tool">Instructor Tools</option>';
-        optiontxt+='<option title="Insert cell below selected and create a data entry table.">Insert Data Entry Table...</option>';
-        optiontxt+='<option title="Prevent editting of selected cells.">Protect Selected Cells</option>';
-        optiontxt+='<option title="Allow editting of selected cells.">Deprotect Selected Cells</option>';
-        optiontxt+='<option title="Temporarily highlight protected cells in pink.">Indicate Protected Cells</option>';
+        var optiontxt = '<option title="Choose an option below"> \
+        Instructor Tools</option>';
+        optiontxt+='<option title="Insert cell below selected and create a \
+        data entry table.">Insert Data Entry Table...</option>';
+        optiontxt+='<option title="Add light blue color bar to left of \
+        markdown cell. Used to indicate instructions.">Mark Cell as \
+        Instructions</option>';
         optiontxt+='<option disabled>----</option>';
-        optiontxt+='<option title="Insert get names and timestamp function into current cell. Also locks the cell to editing.">';
+        optiontxt+='<option title="Prevent editing of selected cells."> \
+        Protect Selected Cells</option>';
+        optiontxt+='<option title="Allow editing of selected cells."> \
+        Deprotect Selected Cells</option>';
+        optiontxt+='<option title="Temporarily highlight protected cells in \
+        pink.">Indicate Protected Cells</option>';
+        optiontxt+='<option disabled>----</option>';
+        optiontxt+='<option title="Set selected cells to hide-on-print."> \
+        Allow Hiding Selected Cells</option>';
+        optiontxt+='<option title="Unset hide-on-print of selected cells."> \
+        Disallow Hiding Selected Cells</option>';
+        optiontxt+='<option title="Temporarily highlight hide-on-print cells \
+        in magenta">Indicate Cells Allowed to Hide</option>';
+        optiontxt+='<option title="Hide cells set to hide-on-print">Test \
+        Hide Cells</option>';
+        optiontxt+='<option title="Redisplay cells set to hide-on-print"> \
+        Undo Hide Cells</option>';
+        optiontxt+='<option disabled>----</option>';
+        optiontxt+='<option title="Insert get names and timestamp function \
+        into current cell. Also locks the cell to editing.">';
         optiontxt+='Insert get names and timestamp</option>';
-        optiontxt+='<option title="Insert boilerplate about initialization in next cell">Insert initialization boilerplate</option>';
-        optiontxt+='<option title="Remove/deactivate this menu. Use python command `import InstructorTools` to reactivate">';
+        optiontxt+='<option title="Insert boilerplate about initialization in \
+        next cell">Insert initialization boilerplate</option>';
+        optiontxt+='<option disabled>----</option>';
+        optiontxt+='<option title="Remove/deactivate this menu. Use python \
+        command `import InstructorTools` to reactivate">';
         optiontxt+='Deactivate this menu</option>';
         optiontxt+='<option title="Remove menu permanently. Blocks reinstalling.">';
         optiontxt+='!deactivate permanently!</option>';
@@ -129,12 +172,59 @@ function mark_protected_cells(){
     }
 }
 
+function set_hide_selected_cells_on_print(){
+    var celllist = Jupyter.notebook.get_selected_cells();
+    for (var i = 0;i<celllist.length;i++){
+        if (!celllist[i].metadata.JPSL){
+        celllist[i].metadata.JPSL={}}
+        celllist[i].metadata.JPSL.hide_on_print=true;
+        celllist[i].element.children()[0].setAttribute("style",
+        "background-color:magenta;");
+        }
+}
+
+function unset_hide_selected_cells_on_print(){
+    var celllist = Jupyter.notebook.get_selected_cells();
+    for (var i = 0;i<celllist.length;i++){
+        if (!celllist[i].metadata.JPSL){
+        celllist[i].metadata.JPSL={}}
+        celllist[i].metadata.JPSL.hide_on_print=false;
+        celllist[i].element.children()[0].removeAttribute("style");
+    }
+}
+
+function mark_hide_on_print_cells(){
+    var celllist = Jupyter.notebook.get_cells();
+    for (var i = 0;i<celllist.length;i++){
+        if (celllist[i].metadata.JPSL){
+            if (celllist[i].metadata.JPSL.hide_on_print==true){
+                celllist[i].element.children()[0].setAttribute("style",
+                "background-color:magenta;");
+                } else {
+                celllist[i].element.children()[0].removeAttribute("style");
+            }
+        }
+    }
+}
+
 function insert_getnames_timestamp(){
     var text = 'import JPSLUtils\nJPSLUtils.record_names_timestamp()';
     JPSLUtils.insert_newline_at_end_of_current_cell(text);
     protect_selected_cells();
 }
 
+function indicate_cell_contains_instructions(){
+    var text = '<div style="border-color:lightblue;border-style:solid; \
+    float:left;height:100%;margin-right:4px;margin-bottom:94px;"></div>\n\n';
+    JPSLUtils.insert_text_at_beginning_of_current_cell(text);
+    var currentcell = Jupyter.notebook.get_selected_cell();
+    var cellindex=Jupyter.notebook.find_cell_index(currentcell);
+    Jupyter.notebook.to_code(cellindex);
+    Jupyter.notebook.to_markdown(cellindex);
+    Jupyter.notebook.focus_cell();
+    Jupyter.notebook.get_selected_cell().execute();
+}
+
 function insert_init_boilerplate(){
     var mkdstr = "### You must initialize the software each time you use \
     this notebook.\n";
@@ -148,7 +238,7 @@ function insert_init_boilerplate(){
     mkdstr += " 2. The cell immediately below contains code that loads the";
     mkdstr += " software modules necessary for this notebook to run. It also";
     mkdstr += " collects some bookkeeping information that can be used for";
-    mkdstr += " troubleshooting. **You must run this cell each time you use";
+    mkdstr += " troubleshooting. **You must run this cell each time you open";
     mkdstr += " the notebook or later cells may not work.**\n";
     mkdstr += " 3. If you are doing calculations that depend upon";
     mkdstr += " using variables passed from calculations done the previous";
